Index: uspace/lib/ext4/src/ops.c
===================================================================
--- uspace/lib/ext4/src/ops.c	(revision 3be9d10120f7923a0b3d52282b8de0b670566c71)
+++ uspace/lib/ext4/src/ops.c	(revision b752a317bb5dfb454cb227f59a1be5d52d10947d)
@@ -1021,8 +1021,8 @@
 	 * Receive the read request.
 	 */
-	cap_call_handle_t callid;
+	cap_call_handle_t chandle;
 	size_t size;
-	if (!async_data_read_receive(&callid, &size)) {
-		async_answer_0(callid, EINVAL);
+	if (!async_data_read_receive(&chandle, &size)) {
+		async_answer_0(chandle, EINVAL);
 		return EINVAL;
 	}
@@ -1031,5 +1031,5 @@
 	errno_t rc = ext4_instance_get(service_id, &inst);
 	if (rc != EOK) {
-		async_answer_0(callid, rc);
+		async_answer_0(chandle, rc);
 		return rc;
 	}
@@ -1039,5 +1039,5 @@
 	rc = ext4_filesystem_get_inode_ref(inst->filesystem, index, &inode_ref);
 	if (rc != EOK) {
-		async_answer_0(callid, rc);
+		async_answer_0(chandle, rc);
 		return rc;
 	}
@@ -1046,13 +1046,13 @@
 	if (ext4_inode_is_type(inst->filesystem->superblock, inode_ref->inode,
 	    EXT4_INODE_MODE_FILE)) {
-		rc = ext4_read_file(callid, pos, size, inst, inode_ref,
+		rc = ext4_read_file(chandle, pos, size, inst, inode_ref,
 		    rbytes);
 	} else if (ext4_inode_is_type(inst->filesystem->superblock,
 	    inode_ref->inode, EXT4_INODE_MODE_DIRECTORY)) {
-		rc = ext4_read_directory(callid, pos, size, inst, inode_ref,
+		rc = ext4_read_directory(chandle, pos, size, inst, inode_ref,
 		    rbytes);
 	} else {
 		/* Other inode types not supported */
-		async_answer_0(callid, ENOTSUP);
+		async_answer_0(chandle, ENOTSUP);
 		rc = ENOTSUP;
 	}
@@ -1084,5 +1084,5 @@
 /** Read data from directory.
  *
  * @param callid    IPC id of call (for communication)
  * @param pos       Position to start reading from
  * @param size      How many bytes to read
@@ -1094,5 +1094,5 @@
  *
  */
-errno_t ext4_read_directory(cap_call_handle_t callid, aoff64_t pos, size_t size,
+errno_t ext4_read_directory(cap_call_handle_t chandle, aoff64_t pos, size_t size,
     ext4_instance_t *inst, ext4_inode_ref_t *inode_ref, size_t *rbytes)
 {
@@ -1100,5 +1100,5 @@
 	errno_t rc = ext4_directory_iterator_init(&it, inode_ref, pos);
 	if (rc != EOK) {
-		async_answer_0(callid, rc);
+		async_answer_0(chandle, rc);
 		return rc;
 	}
@@ -1129,5 +1129,5 @@
 		if (buf == NULL) {
 			ext4_directory_iterator_fini(&it);
-			async_answer_0(callid, ENOMEM);
+			async_answer_0(chandle, ENOMEM);
 			return ENOMEM;
 		}
@@ -1137,5 +1137,5 @@
 		found = true;
 
-		(void) async_data_read_finalize(callid, buf, name_size + 1);
+		(void) async_data_read_finalize(chandle, buf, name_size + 1);
 		free(buf);
 		break;
@@ -1145,5 +1145,5 @@
 		if (rc != EOK) {
 			ext4_directory_iterator_fini(&it);
-			async_answer_0(callid, rc);
+			async_answer_0(chandle, rc);
 			return rc;
 		}
@@ -1168,5 +1168,5 @@
 		return EOK;
 	} else {
-		async_answer_0(callid, ENOENT);
+		async_answer_0(chandle, ENOENT);
 		return ENOENT;
 	}
@@ -1175,5 +1175,5 @@
 /** Read data from file.
  *
  * @param callid    IPC id of call (for communication)
  * @param pos       Position to start reading from
  * @param size      How many bytes to read
@@ -1185,5 +1185,5 @@
  *
  */
-errno_t ext4_read_file(cap_call_handle_t callid, aoff64_t pos, size_t size,
+errno_t ext4_read_file(cap_call_handle_t chandle, aoff64_t pos, size_t size,
     ext4_instance_t *inst, ext4_inode_ref_t *inode_ref, size_t *rbytes)
 {
@@ -1193,5 +1193,5 @@
 	if (pos >= file_size) {
 		/* Read 0 bytes successfully */
-		async_data_read_finalize(callid, NULL, 0);
+		async_data_read_finalize(chandle, NULL, 0);
 		*rbytes = 0;
 		return EOK;
@@ -1213,5 +1213,5 @@
 	    file_block, &fs_block);
 	if (rc != EOK) {
-		async_answer_0(callid, rc);
+		async_answer_0(chandle, rc);
 		return rc;
 	}
@@ -1227,5 +1227,5 @@
 		buffer = malloc(bytes);
 		if (buffer == NULL) {
-			async_answer_0(callid, ENOMEM);
+			async_answer_0(chandle, ENOMEM);
 			return ENOMEM;
 		}
@@ -1233,5 +1233,5 @@
 		memset(buffer, 0, bytes);
 
-		rc = async_data_read_finalize(callid, buffer, bytes);
+		rc = async_data_read_finalize(chandle, buffer, bytes);
 		*rbytes = bytes;
 
@@ -1244,10 +1244,10 @@
 	rc = block_get(&block, inst->service_id, fs_block, BLOCK_FLAGS_NONE);
 	if (rc != EOK) {
-		async_answer_0(callid, rc);
+		async_answer_0(chandle, rc);
 		return rc;
 	}
 
 	assert(offset_in_block + bytes <= block_size);
-	rc = async_data_read_finalize(callid, block->data + offset_in_block, bytes);
+	rc = async_data_read_finalize(chandle, block->data + offset_in_block, bytes);
 	if (rc != EOK) {
 		block_put(block);
@@ -1283,9 +1283,9 @@
 		return rc;
 
-	cap_call_handle_t callid;
+	cap_call_handle_t chandle;
 	size_t len;
-	if (!async_data_write_receive(&callid, &len)) {
+	if (!async_data_write_receive(&chandle, &len)) {
 		rc = EINVAL;
-		async_answer_0(callid, rc);
+		async_answer_0(chandle, rc);
 		goto exit;
 	}
@@ -1311,5 +1311,5 @@
 	    &fblock);
 	if (rc != EOK) {
-		async_answer_0(callid, rc);
+		async_answer_0(chandle, rc);
 		goto exit;
 	}
@@ -1328,5 +1328,5 @@
 				    &fblock, true);
 				if (rc != EOK) {
-					async_answer_0(callid, rc);
+					async_answer_0(chandle, rc);
 					goto exit;
 				}
@@ -1336,5 +1336,5 @@
 			    &fblock, false);
 			if (rc != EOK) {
-				async_answer_0(callid, rc);
+				async_answer_0(chandle, rc);
 				goto exit;
 			}
@@ -1342,5 +1342,5 @@
 			rc = ext4_balloc_alloc_block(inode_ref, &fblock);
 			if (rc != EOK) {
-				async_answer_0(callid, rc);
+				async_answer_0(chandle, rc);
 				goto exit;
 			}
@@ -1350,5 +1350,5 @@
 			if (rc != EOK) {
 				ext4_balloc_free_block(inode_ref, fblock);
-				async_answer_0(callid, rc);
+				async_answer_0(chandle, rc);
 				goto exit;
 			}
@@ -1363,5 +1363,5 @@
 	rc = block_get(&write_block, service_id, fblock, flags);
 	if (rc != EOK) {
-		async_answer_0(callid, rc);
+		async_answer_0(chandle, rc);
 		goto exit;
 	}
@@ -1370,5 +1370,5 @@
 		memset(write_block->data, 0, block_size);
 
-	rc = async_data_write_finalize(callid, write_block->data +
+	rc = async_data_write_finalize(chandle, write_block->data +
 	    (pos % block_size), bytes);
 	if (rc != EOK) {
@@ -1084,5 +1084,5 @@
 /** Read data from directory.
  *
- * @param callid    IPC id of call (for communication)
+ * @param chandle    IPC id of call (for communication)
  * @param pos       Position to start reading from
  * @param size      How many bytes to read
@@ -1175,5 +1175,5 @@
 /** Read data from file.
  *
- * @param callid    IPC id of call (for communication)
+ * @param chandle    IPC id of call (for communication)
  * @param pos       Position to start reading from
  * @param size      How many bytes to read
